PIconnect.Data module
=====================

Data containers
---------------

.. autoclass:: PIconnect.Data.DataContainer
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: PIconnect.Data.DataContainerCollection
    :members:
    :undoc-members:
    :show-inheritance:

AF Enumeration Values
---------------------

.. autoclass:: PIconnect.Data.AFEnumerationValue
    :members:
    :undoc-members:
    :show-inheritance:

Enumerations
------------

.. automodule:: PIconnect.Data
    :members:
    :exclude-members: DataContainer, DataContainerCollection, AFEnumerationValue
    :undoc-members:
    :show-inheritance:
